nagios_host 'bristoluniversitypressdigital.com' do
	options 'use' => 'noping-host-https',
		'alias' => 'BUP',
		'address' => 'bristoluniversitypressdigital.com',
		'contact_groups' => 'cs_escalation,bup',
		'notes' => 'BUP Live Site',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/BUP/pages/2074804270/BUP+-+Server+Setup+Page'
end
nagios_host 'admin.bristoluniversitypressdigital.com' do
	options 'use' => 'noping-host-https',
		'alias' => 'BUP MGMT',
		'address' => 'admin.bristoluniversitypressdigital.com',
		'contact_groups' => 'cs_escalation,bup',
		'notes' => 'BUP Production Management Portal',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/BUP/pages/2074804270/BUP+-+Server+Setup+Page'
end
nagios_host 'ams.bristoluniversitypressdigital.com' do
	options 'use' => 'noping-host-https',
		'alias' => 'BUP AMS',
		'address' => 'ams.bristoluniversitypressdigital.com',
		'contact_groups' => 'cs_escalation,bup',
		'notes' => 'BUP Production AMS',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/BUP/pages/2074804270/BUP+-+Server+Setup+Page'
end
#------------------------------------------------------------------------------------
# HOMEPAGE
# checks the homepage of the live BUP site and checks for the string 'Bristol University'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'bristoluniversitypressdigital.com-Live Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'bristoluniversitypressdigital.com',
		'display_name' => 'Live Homepage',
		'check_command' => 'https_content_check_basic_auth!bup:bup2021!/!"Bristol University"!10!20!',
		'contact_groups' => 'cs_escalation,bup',
		'notes' => 'BUP Live Site',
		'notes_url' => 'https://bristoluniversitypressdigital.com'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 1)
# checks the homepage of the live bup site on the first web node and checks for the string 'Bristol University'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'bristoluniversitypressdigital.com-Live Homepage: bup-web-3' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'bristoluniversitypressdigital.com',
		'display_name' => 'Live Homepage: bup-web-3',
		'check_command' => 'https_content_check_basic_auth_single_node!bup:bup2021!/!"Bristol University"!10!20!bup-web-3-live!bup-web-3.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,bup',
		'notes' => 'BUP Live Site: bup-web-3',
		'notes_url' => 'https://bristoluniversitypressdigital.com'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 2)
# checks the homepage of the live bup site on the sercond web node and checks for the string 'Bristol University'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'bristoluniversitypressdigital.com-Live Homepage: bup-web-4' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'bristoluniversitypressdigital.com',
		'display_name' => 'Live Homepage: bup-web-4',
		'check_command' => 'https_content_check_basic_auth_single_node!bup:bup2021!/!"Bristol University"!10!20!bup-web-4-live!bup-web-4.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,bup',
		'notes' => 'BUP Live Site: bup-web-4',
		'notes_url' => 'https://bristoluniversitypressdigital.com'
end
#------------------------------------------------------------------------------------
# SEARCH
# Checks the search of the live BUP site and checks for the string 'Bristol University'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'bristoluniversitypressdigital.com-Live Search' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'bristoluniversitypressdigital.com',
		'display_name' => 'Live Search',
		'check_command' => 'https_content_check_basic_auth!bup:bup2021!/search!Browse!10!20!',
		'contact_groups' => 'cs_escalation,bup',
		'notes' => 'BUP Live Site',
		'notes_url' => 'https://bristoluniversitypressdigital.com/search'
end
#------------------------------------------------------------------------------------
# SEARCH (NODE 1)
# Checks the search of the live bup site on the first web node and checks for the string 'Bristol University'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'bristoluniversitypressdigital.com-Live Search: bup-web-3' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'bristoluniversitypressdigital.com',
		'display_name' => 'Live search: bup-web-3',
		'check_command' => 'https_content_check_basic_auth_single_node!bup:bup2021!/search!Browse!10!20!bup-web-3-live!bup-web-3.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,bup',
		'notes' => 'BUP Live Site: bup-web-3',
		'notes_url' => 'https://bristoluniversitypressdigital.com/search'
end
#------------------------------------------------------------------------------------
# SEARCH (NODE 2)
# Checks the search of the live bup site on the second web node and checks for the string 'Bristol University'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'bristoluniversitypressdigital.com-Live Search: bup-web-4' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'bristoluniversitypressdigital.com',
		'display_name' => 'Live search: bup-web-4',
		'check_command' => 'https_content_check_basic_auth_single_node!bup:bup2021!/search!Browse!10!20!bup-web-4-live!bup-web-4.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,bup',
		'notes' => 'BUP Live Site: bup-web-4',
		'notes_url' => 'https://bristoluniversitypressdigital.com/search'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW
# checks the content view of the live BUP site and checks for the string 'Bristol University'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'bristoluniversitypressdigital.com-Live content view' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'bristoluniversitypressdigital.com',
		'display_name' => 'Live content view',
		'check_command' => 'https_content_check_basic_auth!bup:bup2021!/view/book/9781529218855/9781529218855.xml!COVID!10!20!',
		'contact_groups' => 'cs_escalation,bup',
		'notes' => 'BUP Live Site',
		'notes_url' => 'https://bristoluniversitypressdigital.com/view/book/9781529218855/9781529218855.xml'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (NODE 1)
# checks the content view of the live bup site on the first web node and checks for the string 'Bristol University'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'bristoluniversitypressdigital.com-Live content view: bup-web-3' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'bristoluniversitypressdigital.com',
		'display_name' => 'Live content view: bup-web-3',
		'check_command' => 'https_content_check_basic_auth_single_node!bup:bup2021!/view/book/9781529218855/9781529218855.xml!COVID!10!20!bup-web-3-live!bup-web-3.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,bup',
		'notes' => 'BUP Live Site: bup-web-3',
		'notes_url' => 'https://bristoluniversitypressdigital.com/view/book/9781529218855/9781529218855.xml'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (NODE 2)
# checks the content view of the live bup site on the sedmond web node and checks for the string 'Bristol University'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'bristoluniversitypressdigital.com-Live content view: bup-web-4' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'bristoluniversitypressdigital.com',
		'display_name' => 'Live content view: bup-web-4',
		'check_command' => 'https_content_check_basic_auth_single_node!bup:bup2021!/view/book/9781529218855/9781529218855.xml!COVID!10!20!bup-web-4-live!bup-web-4.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,bup',
		'notes' => 'BUP Live Site: bup-web-4',
		'notes_url' => 'https://bristoluniversitypressdigital.com/view/book/9781529218855/9781529218855.xml'
end
#------------------------------------------------------------------------------------
# LOADER
# Checks a loader login page and looks for the string 'Login' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'bristoluniversitypressdigital.com-Production Loader' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'admin.bristoluniversitypressdigital.com',
		'display_name' => 'Production Loader',
		'check_command' => 'check_loader_auth!admin.bristoluniversitypressdigital.com!/login!bup:bup2021!"BUP"!20!10',
		'contact_groups' => 'admins_email_only,bup',
		'notes' => 'BUP Live Loader',
		'notes_url' => 'https://admin.bristoluniversitypressdigital.com/login'
end
#------------------------------------------------------------------------------------
# STAGING
# Checks the staging site homepage and looks for the string 'Bristol University' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'bristoluniversitypressdigital.com-Staging Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'bristoluniversitypressdigital.com',
		'display_name' => 'Staging Homepage',
		'check_command' => 'check_staging_auth!staging.bristoluniversitypressdigital.com!bup:bup2021!"Bristol University"!20!10',
		'contact_groups' => 'admins_email_only,bup',
		'notes' => 'BUP Staging Site',
		'notes_url' => 'staging.bristoluniversitypressdigital.com'
end
#------------------------------------------------------------------------------------
# AMX
# Checks the production amx homepage and looks for the string 'AMS' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'bristoluniversitypressdigital.com-Production AMX' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ams.bristoluniversitypressdigital.com',
		'display_name' => 'Production AMX',
		'check_command' => 'check_loader_auth!ams.bristoluniversitypressdigital.com!/login!bup:bup2021!AMS!20!10',
		'contact_groups' => 'admins_email_only,bup',
		'notes' => 'BUP AMX',
		'notes_url' => 'https://ams.bristoluniversitypressdigital.com/login'
end
#------------------------------------------------------------------------------------
# FAIL OPEN
# Checks the production homepage and makes sure we're not in fail open by checking
# that the string "Provisional Account" is NOT in the page.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'bristoluniversitypressdigital.com-Live Site Fail Open' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'bristoluniversitypressdigital.com',
		'display_name' => 'Live Site Fail Open',
		'check_command' => 'http_negate_content_check_basic_auth!bristoluniversitypressdigital.com!bup:bup2021!"provisional account"',
		'contact_groups' => 'admins_email_only,bup',
		'notes' => 'BUP Live Site Failopen',
		'notes_url' => 'https://bristoluniversitypressdigital.com/'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (Node 3)
# Checks the homepage of the live avmajournals.avma site on the bot web node and checks for the string 'BUP'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'bristoluniversitypressdigital.com-Live Homepage: bup-webbot-2 bot node' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'bristoluniversitypressdigital.com',
		'display_name' => 'Live Homepage: bup-webbot-2',
		'check_command' => 'https_content_check_basic_auth_single_node_bot!bup:bup2021!/!BUP!10!20!bup-webbot-2-live!bup-webbot-2.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,bup',
		'notes' => 'bup Site: bup-webbot-2',
		'notes_url' => 'https://www.bristoluniversitypressdigital.com/'
end
#------------------------------------------------------------------------------------
# SEARCH (NODE 3)
# Checks the search of the live avmajournals.avma site on the first bot web node and checks for the string 'Browse'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'bristoluniversitypressdigital.com-Live Search: bup-webbot-2 bot node' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'bristoluniversitypressdigital.com',
		'display_name' => 'Live Search: bup-webbot-2',
		'check_command' => 'https_content_check_basic_auth_single_node_bot!bup:bup2021!/search!Browse!10!20!bup-webbot-2-live!bup-webbot-2.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,bup',
		'notes' => 'bup Site: bup-webbot-2',
		'notes_url' => 'https://www.bristoluniversitypressdigital.com/'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (NODE 3)
# checks the content view of the live bup site on the first web node and checks for the string 'Bristol University'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'bristoluniversitypressdigital.com-Live content view: bup-webbot-2' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'bristoluniversitypressdigital.com',
		'display_name' => 'Live content view: bup-webbot-2',
		'check_command' => 'https_content_check_basic_auth_single_node_bot!bup:bup2021!/view/book/9781529218855/9781529218855.xml!COVID!10!20!bup-webbot-2-live!bup-webbot-2.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,bup',
		'notes' => 'BUP Live Site: bup-webbot-2',
		'notes_url' => 'https://bristoluniversitypressdigital.com/view/book/9781529218855/9781529218855.xml'
end

